# Citation

If you find PLINDER useful, please cite:

> Janani Durairaj, Yusuf Adeshina, Zhonglin Cao, Xuejin Zhang, Vladas Oleinikovas,
Thomas Duignan, Zachary McClure, Xavier Robin, Gabriel Studer, Daniel Kovtun,
Emanuele Rossi, Guoqing Zhou, Srimukh Veccham, Clemens Isert, Yuxing Peng,
Prabindh Sundareson, Mehmet Akdel, Gabriele Corso, Hannes Stärk, Gerardo Tauriello,
Zachary Carpenter, Michael Bronstein, Emine Kucukbenli, Torsten Schwede, Luca Naef,\
"PLINDER: The protein-ligand interactions dataset and evaluation resource",\
_bioRxiv_
July 2024;
doi: [10.1101/2024.07.17.603955](https://doi.org/10.1101/2024.07.17.603955)

You may also get a useful summary from the
[ICML'24 ML4LMS poster submission](https://openreview.net/forum?id=7UvbaTrNbP).
